==> jetpack.15.4.zip: jetpack/jetpack_vendor/automattic/jetpack-external-connections/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.10] - 2025-12-22
### Changed
- Update dependencies. [#46381]

## [0.1.9] - 2025-12-15
### Changed
- Internal updates.

## [0.1.8] - 2025-12-08
### Fixed
- Ensure proper flags are used with `json_encode()`. [#46092]

## [0.1.7] - 2025-12-01
### Changed
- Update package dependencies. [#46143]

## [0.1.6] - 2025-11-17
### Changed
- Update package dependencies. [#45915]

## [0.1.5] - 2025-11-03
### Changed
- Update dependencies. [#45664]

## [0.1.4] - 2025-10-06
### Changed
- Update package dependencies. [#45334]

## [0.1.3] - 2025-09-22
### Changed
- Update dependencies.

## [0.1.2] - 2025-09-19
### Changed
- Update package dependencies. [#45173] [#45229]

## [0.1.1] - 2025-09-08
### Changed
- Update package dependencies. [#45027]

## 0.1.0 - 2025-09-01
### Added
- Initial version. [#44858]

[0.1.10]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.9...v0.1.10
[0.1.9]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.8...v0.1.9
[0.1.8]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.7...v0.1.8
[0.1.7]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.6...v0.1.7
[0.1.6]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.5...v0.1.6
[0.1.5]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.4...v0.1.5
[0.1.4]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.3...v0.1.4
[0.1.3]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.2...v0.1.3
[0.1.2]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.1...v0.1.2
[0.1.1]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.0...v0.1.1

==> jetpack.15.5.zip: jetpack/jetpack_vendor/automattic/jetpack-external-connections/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.14] - 2026-02-02
### Changed
- Update package dependencies. [#46854]

## [0.1.13] - 2026-01-26
### Changed
- Update dependencies. [#46383]

## [0.1.12] - 2026-01-19
### Changed
- Update package dependencies. [#46552] [#46647]

## [0.1.11] - 2026-01-12
### Changed
- Update package dependencies. [#46456]

## [0.1.10] - 2025-12-22
### Changed
- Update dependencies. [#46381]

## [0.1.9] - 2025-12-15
### Changed
- Internal updates.

## [0.1.8] - 2025-12-08
### Fixed
- Ensure proper flags are used with `json_encode()`. [#46092]

## [0.1.7] - 2025-12-01
### Changed
- Update package dependencies. [#46143]

## [0.1.6] - 2025-11-17
### Changed
- Update package dependencies. [#45915]

## [0.1.5] - 2025-11-03
### Changed
- Update dependencies. [#45664]

## [0.1.4] - 2025-10-06
### Changed
- Update package dependencies. [#45334]

## [0.1.3] - 2025-09-22
### Changed
- Update dependencies.

## [0.1.2] - 2025-09-19
### Changed
- Update package dependencies. [#45173] [#45229]

## [0.1.1] - 2025-09-08
### Changed
- Update package dependencies. [#45027]

## 0.1.0 - 2025-09-01
### Added
- Initial version. [#44858]

[0.1.14]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.13...v0.1.14
[0.1.13]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.12...v0.1.13
[0.1.12]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.11...v0.1.12
[0.1.11]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.10...v0.1.11
[0.1.10]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.9...v0.1.10
[0.1.9]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.8...v0.1.9
[0.1.8]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.7...v0.1.8
[0.1.7]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.6...v0.1.7
[0.1.6]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.5...v0.1.6
[0.1.5]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.4...v0.1.5
[0.1.4]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.3...v0.1.4
[0.1.3]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.2...v0.1.3
[0.1.2]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.1...v0.1.2
[0.1.1]: https://github.com/Automattic/jetpack-external-connections/compare/v0.1.0...v0.1.1
